:program:`mumott`
*****************

:program:`mumott` is a Python library for the analysis of photon probe tensor tomography data.

.. toctree::
   :maxdepth: 2
   :caption: Main

   background

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/inspect_data
   tutorials/reconstruct_and_visualize
   tutorials/projection_and_adjoint

.. toctree::
   :maxdepth: 2
   :caption: Function reference

   moduleref/data_handling
   moduleref/methods
   moduleref/optimization
   moduleref/output_handling
   moduleref/core

.. toctree::
   :maxdepth: 2
   :caption: Backmatter

   bibliography
   glossary
   genindex
